==> estateplat-common-1.2.4-20201113.071717-503-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QlfQlYgdjBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.QlfQlYgdj;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class QlfQlYgdjBdc extends QlfQlYgdj {
    private String dfywrzjzldm;
    private String dfywrzjzlmc;
    private String dfygdjzldm;
    private String dfygdjzlmc;
    private String dfdjlxdm;
    private String dfdjlxmc;
    private String dfghytdm;
    private String dfghytmc;
    private String dffwxzdm;
    private String dffwxzmc;
    private String dffwjgdm;
    private String dffwjgmc;

    @XmlAttribute(
            name = "DFYWRZJZLDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfywrzjzldm() {
        return dfywrzjzldm;
    }

    public void setDfywrzjzldm(String dfywrzjzldm) {
        this.dfywrzjzldm = dfywrzjzldm;
    }
    @XmlAttribute(
            name = "DFYWRZJZLMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfywrzjzlmc() {
        return dfywrzjzlmc;
    }

    public void setDfywrzjzlmc(String dfywrzjzlmc) {
        this.dfywrzjzlmc = dfywrzjzlmc;
    }
    @XmlAttribute(
            name = "DFYGDJZLDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfygdjzldm() {
        return dfygdjzldm;
    }

    public void setDfygdjzldm(String dfygdjzldm) {
        this.dfygdjzldm = dfygdjzldm;
    }
    @XmlAttribute(
            name = "DFYGDJZLMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfygdjzlmc() {
        return dfygdjzlmc;
    }

    public void setDfygdjzlmc(String dfygdjzlmc) {
        this.dfygdjzlmc = dfygdjzlmc;
    }
    @XmlAttribute(
            name = "DFDJLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfdjlxdm() {
        return dfdjlxdm;
    }

    public void setDfdjlxdm(String dfdjlxdm) {
        this.dfdjlxdm = dfdjlxdm;
    }
    @XmlAttribute(
            name = "DFDJLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfdjlxmc() {
        return dfdjlxmc;
    }

    public void setDfdjlxmc(String dfdjlxmc) {
        this.dfdjlxmc = dfdjlxmc;
    }
    @XmlAttribute(
            name = "DFGHYTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfghytdm() {
        return dfghytdm;
    }

    public void setDfghytdm(String dfghytdm) {
        this.dfghytdm = dfghytdm;
    }

    @XmlAttribute(
            name = "DFGHYTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfghytmc() {
        return dfghytmc;
    }

    public void setDfghytmc(String dfghytmc) {
        this.dfghytmc = dfghytmc;
    }
    @XmlAttribute(
            name = "DFFWXZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDffwxzdm() {
        return dffwxzdm;
    }

    public void setDffwxzdm(String dffwxzdm) {
        this.dffwxzdm = dffwxzdm;
    }
    @XmlAttribute(
            name = "DFFWXZMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDffwxzmc() {
        return dffwxzmc;
    }

    public void setDffwxzmc(String dffwxzmc) {
        this.dffwxzmc = dffwxzmc;
    }
    @XmlAttribute(
            name = "DFFWJGDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDffwjgdm() {
        return dffwjgdm;
    }

    public void setDffwjgdm(String dffwjgdm) {
        this.dffwjgdm = dffwjgdm;
    }
    @XmlAttribute(
            name = "DFFWJGMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDffwjgmc() {
        return dffwjgmc;
    }

    public void setDffwjgmc(String dffwjgmc) {
        this.dffwjgmc = dffwjgmc;
    }
}

==> estateplat-common-1.2.4-20201203.071103-573-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QlfQlYgdjBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.QlfQlYgdj;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class QlfQlYgdjBdc extends QlfQlYgdj {
    private String dfywrzjzldm;
    private String dfywrzjzlmc;
    private String dfygdjzldm;
    private String dfygdjzlmc;
    private String dfdjlxdm;
    private String dfdjlxmc;
    private String dfghytdm;
    private String dfghytmc;
    private String dffwxzdm;
    private String dffwxzmc;
    private String dffwjgdm;
    private String dffwjgmc;

    @XmlAttribute(
            name = "DFYWRZJZLDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfywrzjzldm() {
        return dfywrzjzldm;
    }

    public void setDfywrzjzldm(String dfywrzjzldm) {
        this.dfywrzjzldm = dfywrzjzldm;
    }
    @XmlAttribute(
            name = "DFYWRZJZLMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfywrzjzlmc() {
        return dfywrzjzlmc;
    }

    public void setDfywrzjzlmc(String dfywrzjzlmc) {
        this.dfywrzjzlmc = dfywrzjzlmc;
    }
    @XmlAttribute(
            name = "DFYGDJZLDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfygdjzldm() {
        return dfygdjzldm;
    }

    public void setDfygdjzldm(String dfygdjzldm) {
        this.dfygdjzldm = dfygdjzldm;
    }
    @XmlAttribute(
            name = "DFYGDJZLMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfygdjzlmc() {
        return dfygdjzlmc;
    }

    public void setDfygdjzlmc(String dfygdjzlmc) {
        this.dfygdjzlmc = dfygdjzlmc;
    }
    @XmlAttribute(
            name = "DFDJLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxdm() {
        return dfdjlxdm;
    }

    public void setDfdjlxdm(String dfdjlxdm) {
        this.dfdjlxdm = dfdjlxdm;
    }
    @XmlAttribute(
            name = "DFDJLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxmc() {
        return dfdjlxmc;
    }

    public void setDfdjlxmc(String dfdjlxmc) {
        this.dfdjlxmc = dfdjlxmc;
    }
    @XmlAttribute(
            name = "DFGHYTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfghytdm() {
        return dfghytdm;
    }

    public void setDfghytdm(String dfghytdm) {
        this.dfghytdm = dfghytdm;
    }

    @XmlAttribute(
            name = "DFGHYTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfghytmc() {
        return dfghytmc;
    }

    public void setDfghytmc(String dfghytmc) {
        this.dfghytmc = dfghytmc;
    }
    @XmlAttribute(
            name = "DFFWXZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwxzdm() {
        return dffwxzdm;
    }

    public void setDffwxzdm(String dffwxzdm) {
        this.dffwxzdm = dffwxzdm;
    }
    @XmlAttribute(
            name = "DFFWXZMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwxzmc() {
        return dffwxzmc;
    }

    public void setDffwxzmc(String dffwxzmc) {
        this.dffwxzmc = dffwxzmc;
    }
    @XmlAttribute(
            name = "DFFWJGDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwjgdm() {
        return dffwjgdm;
    }

    public void setDffwjgdm(String dffwjgdm) {
        this.dffwjgdm = dffwjgdm;
    }
    @XmlAttribute(
            name = "DFFWJGMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwjgmc() {
        return dffwjgmc;
    }

    public void setDffwjgmc(String dffwjgmc) {
        this.dffwjgmc = dffwjgmc;
    }
}
